==> haskell-unordered-containers-0.2.7.2-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.7.2
id: unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
key: unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
license: BSD3
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
author: Johan Tibell
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.PopCount Data.HashMap.Unsafe Data.HashMap.UnsafeShift
abi: 176fe6df83dc59075a29d5e28030fcfe
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.7.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/unordered-containers-0.2.7.2
hs-libraries: HSunordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unordered-containers-0.2.8.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unordered-containers
version: 0.2.8.0
id: unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
key: unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
license: BSD3
copyright: 2010-2014 Johan Tibell
           2010 Edward Z. Yang
maintainer: johan.tibell@gmail.com
homepage: https://github.com/tibbe/unordered-containers
synopsis: Efficient hashing-based container types
description:
    Efficient hashing-based container types.  The containers have been
    optimized for performance critical use, both in terms of large data
    quantities and high speed.
    .
    The declared cost of each operation is either worst-case or
    amortized, but remains valid even if structures are shared.
category: Data
author: Johan Tibell
exposed: True
exposed-modules:
    Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
hidden-modules: Data.HashMap.Array Data.HashMap.Base
                Data.HashMap.PopCount Data.HashMap.Unsafe Data.HashMap.UnsafeShift
abi: 29da7d5234c802908ede9eab806b1e69
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.8.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/unordered-containers-0.2.8.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/unordered-containers-0.2.8.0
hs-libraries: HSunordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
depends:
    base-4.9.0.0 deepseq-1.4.2.0
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
haddock-interfaces: /usr/share/doc/haskell-unordered-containers/html/unordered-containers.haddock
haddock-html: /usr/share/doc/haskell-unordered-containers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
